@@ -1,5 +1,5 @@
 package HackaMol;
-$HackaMol::VERSION = '0.035';
+$HackaMol::VERSION = '0.036';
 #ABSTRACT: HackaMol: Object-Oriented Library for Molecular Hacking
 use 5.008;
 use Moose;
@@ -55,6 +55,16 @@ sub read_file_mol{
     return (HackaMol::Molecule->new(name=>$name, atoms=>[@atoms]));
 }
 
+sub read_string_mol{
+    my $self = shift;
+    my $string = shift;
+    my $format = shift or croak "must pass format: xyz, pdb, pdbqt, zmat, yaml";
+
+    my @atoms = $self->read_string_atoms($string,$format);
+    my $name = $format. ".mol";
+    return (HackaMol::Molecule->new(name=>$name, atoms=>[@atoms]));
+}
+
 sub build_bonds {
 
     #take a list of n, atoms; walk down list and generate bonds
@@ -291,7 +301,7 @@ HackaMol - HackaMol: Object-Oriented Library for Molecular Hacking
 
 =head1 VERSION
 
-version 0.035
+version 0.036
 
 =head1 DESCRIPTION
 
