@@ -1,5 +1,5 @@
 package HackaMol::Roles::MolReadRole;
-$HackaMol::Roles::MolReadRole::VERSION = '0.035';
+$HackaMol::Roles::MolReadRole::VERSION = '0.036';
 # ABSTRACT: Read files with molecular information
 use Moose::Role;
 use Carp;
@@ -25,9 +25,42 @@ has 'hush_read' => (
     default => 0,
 );
 
+sub read_string_atoms {
+    my $self   = shift;
+    my $string = shift;  
+    my $type   = shift or croak "must pass format: xyz, pdb, pdbqt, zmat, yaml";
+
+    open (my $fh, '<', \$string) or croak "unable to open string";
+
+    my @atoms;
+
+    if ( $type eq 'pdb' ) {
+        @atoms = $self->read_pdb_atoms($fh);
+    }
+    elsif ( $type eq 'pdbqt') {
+        @atoms = $self->read_pdbqt_atoms($fh);
+    }
+    elsif ( $type eq 'xyz') {
+        @atoms = $self->read_xyz_atoms($fh);
+    }
+    elsif ( $type eq 'zmat') {
+        @atoms = $self->read_zmat_atoms($fh);
+    }
+    elsif ( $type eq 'yaml') {
+        $fh->close;
+        $fh = Loadtype($type); 
+        @atoms = $self->read_yaml_atoms($fh);
+    }
+    else {
+        croak "$type format not supported";
+    }
+    return (@atoms);
+}
+
 sub read_file_atoms {
     my $self = shift;
     my $file = shift;
+ 
     my $fh   = FileHandle->new("<$file") or croak "unable to open $file";
 
     my @atoms;
@@ -70,7 +103,7 @@ HackaMol::Roles::MolReadRole - Read files with molecular information
 
 =head1 VERSION
 
-version 0.035
+version 0.036
 
 =head1 SYNOPSIS
 
@@ -113,6 +146,12 @@ one argument: the name of a file (.xyz, .pdb, .pdbqt, .zmat)
 
 returns a list of HackaMol::Atom objects
 
+=head2 read_string_atoms
+
+two arguments: 1. a string with coordinates properly formatted; 2. format (xyz, pdb, pdbqt, zmat, yaml)
+
+returns a list of HackaMol::Atom objects
+
 =head1 ATTRIBUTES
 
 =head2 hush_read
